==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/he.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "פרטיות",
    "-" : "-",
    "Your data is located in: " : "הנתונים שלך נמצאים תחת:",
    "The admin hasn't selected the location of the server yet." : "המנהל לא בחר את מיקום השרת עדיין.",
    "Please select a country" : "נא לבחור מדינה",
    "You don't have any shares with individual users." : "אין לך שיתופים עם משתמשים בודדים.",
    "Somaliland" : "סומלילנד",
    "United Arab Emirates" : "איחוד האמירויות הערביות",
    "Afghanistan" : "אפגניסטן",
    "Albania" : "אלבניה",
    "Armenia" : "ארמניה",
    "Angola" : "אנגולה",
    "Argentina" : "ארגנטינה",
    "Austria" : "אוסטריה",
    "Australia" : "אוסטרליה",
    "Azerbaijan" : "אזרבייג׳ן",
    "Bosnia and Herzegowina" : "בוסניה והרצגובינה",
    "Bangladesh" : "בנגלדש",
    "Belgium" : "בלגיה",
    "Burkina Faso" : "בורקינה פאסו",
    "Bulgaria" : "בולגריה",
    "Burundi" : "בורונדי",
    "Benin" : "בנין",
    "Brunei" : "ברוניי",
    "Bolivia" : "בוליביה",
    "Brazil" : "ברזיל",
    "Bahamas" : "איי בהאמה",
    "Bhutan" : "בהוטן",
    "Botswana" : "בוטסואנה",
    "Belarus" : "בלרוס",
    "Belize" : "בליז",
    "Canada" : "קנדה",
    "Democratic Republic of the Congo" : "הרפובליקה הדמוקרטית של קונגו",
    "Central African Republic" : "הרפובליקה המרכז-אפריקאית",
    "Congo" : "קונגו",
    "Switzerland" : "שווייץ",
    "Cote d'Ivoire" : "חוף השנהב",
    "Chile" : "צ׳ילה",
    "Cameroon" : "קמרון",
    "China" : "סין",
    "Colombia" : "קולומביה",
    "Costa Rica" : "קוסטה ריקה",
    "Cuba" : "קובה",
    "Cyprus" : "קפריסין",
    "Czech" : "צ׳כיה",
    "Germany" : "גרמניה",
    "Djibouti" : "ג׳יבוטי",
    "Denmark" : "דנמרק",
    "Dominican Republic" : "הרפובליקה הדומיניקנית",
    "Algeria" : "אלג׳יריה",
    "Ecuador" : "אקוודור",
    "Estonia" : "אסטוניה",
    "Egypt" : "מצרים",
    "West Sahara" : "סהרה המערבית",
    "Eritrea" : "אריתריאה",
    "Spain" : "ספרד",
    "Ethiopia" : "אתיופיה",
    "Finland" : "פינלנד",
    "Fiji" : "פיג׳י",
    "Falkland Islands" : "איי פוקלנד",
    "France" : "צרפת",
    "Gabon" : "גבון",
    "United Kingdom" : "הממלכה המאוחדת",
    "Georgia" : "גאורגיה",
    "Ghana" : "גאנה",
    "Greenland" : "גרינלנד",
    "Gambia" : "גמביה",
    "Guinea" : "גינאה",
    "Equatorial Guinea" : "גינאה המשוונית",
    "Greece" : "יוון",
    "Guatemala" : "גואטמלה",
    "Guinea-Bissau" : "גינאה ביסאו",
    "Guyana" : "גיאנה",
    "Honduras" : "הונדורס",
    "Croatia" : "קרואטיה",
    "Haiti" : "האיטי",
    "Hungary" : "הונגריה",
    "Indonesia" : "אינדונזיה",
    "Ireland" : "אירלנד",
    "Israel" : "ישראל",
    "India" : "הודו",
    "Iraq" : "עיראק",
    "Iran" : "איראן",
    "Iceland" : "איסלנד",
    "Italy" : "איטליה",
    "Jamaica" : "ג׳מייקה",
    "Jordan" : "ירדן",
    "Japan" : "יפן",
    "Kenya" : "קניה",
    "Kyrgyzstan" : "קירגיסטן",
    "Cambodia" : "קמבודיה",
    "North Korea" : "קוריאה הצפונית",
    "South Korea" : "קוריאה הדרומית",
    "Kuwait" : "כווית",
    "Kazakhstan" : "קזחסטן",
    "Laos" : "לאוס",
    "Lebanon" : "לבנון",
    "Sri Lanka" : "סרי לנקה",
    "Liberia" : "ליבריה",
    "Lesotho" : "לסוטו",
    "Lithuania" : "ליטא",
    "Luxembourg" : "לוקסמבורג",
    "Latvia" : "לטביה",
    "Libya" : "לוב",
    "Morocco" : "מרוקו",
    "Moldova" : "מולדובה",
    "Montenegro" : "מונטנגרו",
    "Madagascar" : "מדגסקר",
    "Macedonia" : "מקדוניה",
    "Mali" : "מאלי",
    "Myanmar" : "מיאנמר",
    "Mongolia" : "מונגוליה",
    "Mauritania" : "מאוריטניה",
    "Malawi" : "מלאווי",
    "Mexico" : "מקסיקו",
    "Malaysia" : "מלזיה",
    "Mozambique" : "מוזמביק",
    "Namibia" : "נמיביה",
    "New Caledonia" : "קלדוניה החדשה",
    "Niger" : "ניז׳ר",
    "Nigeria" : "ניגריה",
    "Nicaragua" : "ניקרגואה",
    "Netherlands" : "הולנד",
    "Norway" : "נורווגיה",
    "Nepal" : "נפאל",
    "New Zealand" : "ניו זילנד",
    "Oman" : "עומאן",
    "Panama" : "פנמה",
    "Peru" : "פרו",
    "Papua New Guinea" : "פפואה גינאה החדשה",
    "Philippines" : "הפיליפינים",
    "Pakistan" : "פקיסטן",
    "Poland" : "פולין",
    "Puerto Rico" : "פוארטו ריקו",
    "Portugal" : "פורטוגל",
    "Paraguay" : "פרגוואי",
    "Qatar" : "קטאר",
    "Romania" : "רומניה",
    "Serbia" : "סרביה",
    "Russia" : "רוסיה",
    "Rwanda" : "רואנדה",
    "Saudi Arabia" : "ערב הסעודית",
    "Solomon Islands" : "איי שלמה",
    "Sudan" : "סודאן",
    "Sweden" : "שוודיה",
    "Singapore" : "סינגפור",
    "Slovenia" : "סלובניה",
    "Slovakia" : "סלובקיה",
    "Sierra Leone" : "סיירה לאון",
    "Senegal" : "סנגל",
    "Somalia" : "סומליה",
    "Suriname" : "סורינאם",
    "South Sudan" : "דרום סודאן",
    "El Salvador" : "אל סלוודור",
    "Syria" : "סוריה",
    "Swaziland" : "אסוואטיני",
    "Chad" : "צ׳אד",
    "Fr. S. Antarctic Lands" : "הארצות הדרומיות והאנטארקטיות של צרפת",
    "Togo" : "טוגו",
    "Thailand" : "תאילנד",
    "Tajikistan" : "טג׳יקיסטן",
    "Timor-Leste" : "מזרח טימור",
    "Turkmenistan" : "טורקמניסטן",
    "Tunisia" : "תוניסיה",
    "Turkey" : "טורקיה",
    "Trinidad and Tobago" : "טרינידד וטובגו",
    "Taiwan" : "טאיוואן",
    "Tanzania" : "טנזניה",
    "Ukraine" : "אוקראינה",
    "Uganda" : "אוגנדה",
    "United States" : "ארצות הברית",
    "Uruguay" : "אורוגוואי",
    "Uzbekistan" : "אוזבקיסטן",
    "Venezuela" : "ונצואלה",
    "Vietnam" : "וייטנאם",
    "Vanuatu" : "ונואטו",
    "Yemen" : "תימן",
    "South Africa" : "דרום אפריקה",
    "Zambia" : "זמביה",
    "Zimbabwe" : "זימבבואה",
    "Your Nextcloud account" : "חשבון ה־Nextcloud שלך",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "הנתונים שלך מייצגים את מי שאתה וניתן לנצל אותם לרעה בקלות. אנחנו ב־Nextcloud מאמינים שיש לך את הזכות לבחור מה קורה לנתונים שלך. הזכויות שלך מוגנות עם Nextcloud כפי שמופיע בהצהרת נתוני המשתמשים!",
    "User Data Manifesto 2.0" : "הצהרת נתוני המשתמשים 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "הגדרת זכויות בסיסיות לשליטתם של האנשים בנתונים שלהם עצמם בעידן האינטרנט",
    "Control" : "שליטה",
    "over user data access" : "בגישה לנתוני משתמשים",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "הנתונים שנשלחים בצורה רצונית ומפורשת על ידי המשתמש אמורים להיות תחת שליטת המשתמש. למשתמשים אמורה להיות היכולת להחליט למי להעניק גישה ישירה לנתונים שלהם ותחת אילו הרשאות ורישיונות יש לאפשר את הגישה הזאת.",
    "Knowledge" : "ידע",
    "of how the data is stored" : "על אופן אחסון הנתונים",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "כאשר הנתונים נשלחים לספק שירות מסוים, יש ליידע את המשתמשים בנוגע למיקום בו ספק השירות מאחסן את הנתונים, למשך כמה זמן, תחת איזו סמכות מקומית ספק השירות פועל ואילו חוקים חלים.",
    "Freedom" : "חופש",
    "to choose a platform" : "לבחור פלטפורמה",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "המשתמשים יכולים לחלץ את הנתונים שלהם מהשירות בכל עת ללא אף נעילת ספק. כדי להבטיח זאת נדרש יישום מובנה של סוגי קבצים ופרוטוקולים שהכרחיים לתהליך.",
    "Learn more ↗" : "מידע נוסף ↖ ",
    "Where is your data?" : "איפה הנתונים שלך?",
    "Who has access to your data?" : "למי יש גישה לנתונים שלך?",
    "Administrators" : "מנהלים",
    "People you shared with" : "אנשים אתם שיתפת",
    "Privacy policy" : "מדיניות פרטיות",
    "Read the privacy policy." : "הצגת מדיניות הפרטיות."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/he.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "פרטיות",
    "-" : "-",
    "Add external admin" : "הוספת הנהלה חיצונית",
    "Your files are not protected by encryption." : "הקבצים שלך אינם מוגנים בהצפנה.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "הקבצים שלך מוצפנים עם {linkopen}הצפנה בצד השרת ↖{linkclose}.",
    "This server is protected with full-disk-encryption." : "שרת זה מוגן בהצפנה על כל הכונן.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "הקבצים שלך מוצפנים עם {linkopen}הצפנה בצד השרת ↖{linkclose}. בנוסף, השרת הזה מוגן עם הצפנה על כל הכונן.",
    "This server is using full-disk-encryption." : "השרת הזה משתמש בהצפנה על כל הכונן.",
    "Your data is located in: " : "הנתונים שלך נמצאים תחת:",
    "The admin hasn't selected the location of the server yet." : "המנהל לא בחר את מיקום השרת עדיין.",
    "Please select a country" : "נא לבחור מדינה",
    "You don't have any shares with individual users." : "אין לך שיתופים עם משתמשים בודדים.",
    "Somaliland" : "סומלילנד",
    "United Arab Emirates" : "איחוד האמירויות הערביות",
    "Afghanistan" : "אפגניסטן",
    "Albania" : "אלבניה",
    "Armenia" : "ארמניה",
    "Angola" : "אנגולה",
    "Argentina" : "ארגנטינה",
    "Austria" : "אוסטריה",
    "Australia" : "אוסטרליה",
    "Azerbaijan" : "אזרבייג׳ן",
    "Bosnia and Herzegowina" : "בוסניה והרצגובינה",
    "Bangladesh" : "בנגלדש",
    "Belgium" : "בלגיה",
    "Burkina Faso" : "בורקינה פאסו",
    "Bulgaria" : "בולגריה",
    "Burundi" : "בורונדי",
    "Benin" : "בנין",
    "Brunei" : "ברוניי",
    "Bolivia" : "בוליביה",
    "Brazil" : "ברזיל",
    "Bahamas" : "איי בהאמה",
    "Bhutan" : "בהוטן",
    "Botswana" : "בוטסואנה",
    "Belarus" : "בלרוס",
    "Belize" : "בליז",
    "Canada" : "קנדה",
    "Democratic Republic of the Congo" : "הרפובליקה הדמוקרטית של קונגו",
    "Central African Republic" : "הרפובליקה המרכז-אפריקאית",
    "Congo" : "קונגו",
    "Switzerland" : "שווייץ",
    "Cote d'Ivoire" : "חוף השנהב",
    "Chile" : "צ׳ילה",
    "Cameroon" : "קמרון",
    "China" : "סין",
    "Colombia" : "קולומביה",
    "Costa Rica" : "קוסטה ריקה",
    "Cuba" : "קובה",
    "Cyprus" : "קפריסין",
    "Czech" : "צ׳כיה",
    "Germany" : "גרמניה",
    "Djibouti" : "ג׳יבוטי",
    "Denmark" : "דנמרק",
    "Dominican Republic" : "הרפובליקה הדומיניקנית",
    "Algeria" : "אלג׳יריה",
    "Ecuador" : "אקוודור",
    "Estonia" : "אסטוניה",
    "Egypt" : "מצרים",
    "West Sahara" : "סהרה המערבית",
    "Eritrea" : "אריתריאה",
    "Spain" : "ספרד",
    "Ethiopia" : "אתיופיה",
    "Finland" : "פינלנד",
    "Fiji" : "פיג׳י",
    "Falkland Islands" : "איי פוקלנד",
    "France" : "צרפת",
    "Gabon" : "גבון",
    "United Kingdom" : "הממלכה המאוחדת",
    "Georgia" : "גאורגיה",
    "Ghana" : "גאנה",
    "Greenland" : "גרינלנד",
    "Gambia" : "גמביה",
    "Guinea" : "גינאה",
    "Equatorial Guinea" : "גינאה המשוונית",
    "Greece" : "יוון",
    "Guatemala" : "גואטמלה",
    "Guinea-Bissau" : "גינאה ביסאו",
    "Guyana" : "גיאנה",
    "Honduras" : "הונדורס",
    "Croatia" : "קרואטיה",
    "Haiti" : "האיטי",
    "Hungary" : "הונגריה",
    "Indonesia" : "אינדונזיה",
    "Ireland" : "אירלנד",
    "Israel" : "ישראל",
    "India" : "הודו",
    "Iraq" : "עיראק",
    "Iran" : "איראן",
    "Iceland" : "איסלנד",
    "Italy" : "איטליה",
    "Jamaica" : "ג׳מייקה",
    "Jordan" : "ירדן",
    "Japan" : "יפן",
    "Kenya" : "קניה",
    "Kyrgyzstan" : "קירגיסטן",
    "Cambodia" : "קמבודיה",
    "North Korea" : "קוריאה הצפונית",
    "South Korea" : "קוריאה הדרומית",
    "Kuwait" : "כווית",
    "Kazakhstan" : "קזחסטן",
    "Laos" : "לאוס",
    "Lebanon" : "לבנון",
    "Sri Lanka" : "סרי לנקה",
    "Liberia" : "ליבריה",
    "Lesotho" : "לסוטו",
    "Lithuania" : "ליטא",
    "Luxembourg" : "לוקסמבורג",
    "Latvia" : "לטביה",
    "Libya" : "לוב",
    "Morocco" : "מרוקו",
    "Moldova" : "מולדובה",
    "Montenegro" : "מונטנגרו",
    "Madagascar" : "מדגסקר",
    "Macedonia" : "מקדוניה",
    "Mali" : "מאלי",
    "Myanmar" : "מיאנמר",
    "Mongolia" : "מונגוליה",
    "Mauritania" : "מאוריטניה",
    "Malawi" : "מלאווי",
    "Mexico" : "מקסיקו",
    "Malaysia" : "מלזיה",
    "Mozambique" : "מוזמביק",
    "Namibia" : "נמיביה",
    "New Caledonia" : "קלדוניה החדשה",
    "Niger" : "ניז׳ר",
    "Nigeria" : "ניגריה",
    "Nicaragua" : "ניקרגואה",
    "Netherlands" : "הולנד",
    "Norway" : "נורווגיה",
    "Nepal" : "נפאל",
    "New Zealand" : "ניו זילנד",
    "Oman" : "עומאן",
    "Panama" : "פנמה",
    "Peru" : "פרו",
    "Papua New Guinea" : "פפואה גינאה החדשה",
    "Philippines" : "הפיליפינים",
    "Pakistan" : "פקיסטן",
    "Poland" : "פולין",
    "Puerto Rico" : "פוארטו ריקו",
    "Portugal" : "פורטוגל",
    "Paraguay" : "פרגוואי",
    "Qatar" : "קטאר",
    "Romania" : "רומניה",
    "Serbia" : "סרביה",
    "Russia" : "רוסיה",
    "Rwanda" : "רואנדה",
    "Saudi Arabia" : "ערב הסעודית",
    "Solomon Islands" : "איי שלמה",
    "Sudan" : "סודאן",
    "Sweden" : "שוודיה",
    "Singapore" : "סינגפור",
    "Slovenia" : "סלובניה",
    "Slovakia" : "סלובקיה",
    "Sierra Leone" : "סיירה לאון",
    "Senegal" : "סנגל",
    "Somalia" : "סומליה",
    "Suriname" : "סורינאם",
    "South Sudan" : "דרום סודאן",
    "El Salvador" : "אל סלוודור",
    "Syria" : "סוריה",
    "Swaziland" : "אסוואטיני",
    "Chad" : "צ׳אד",
    "Fr. S. Antarctic Lands" : "הארצות הדרומיות והאנטארקטיות של צרפת",
    "Togo" : "טוגו",
    "Thailand" : "תאילנד",
    "Tajikistan" : "טג׳יקיסטן",
    "Timor-Leste" : "מזרח טימור",
    "Turkmenistan" : "טורקמניסטן",
    "Tunisia" : "תוניסיה",
    "Turkey" : "טורקיה",
    "Trinidad and Tobago" : "טרינידד וטובגו",
    "Taiwan" : "טאיוואן",
    "Tanzania" : "טנזניה",
    "Ukraine" : "אוקראינה",
    "Uganda" : "אוגנדה",
    "United States" : "ארצות הברית",
    "Uruguay" : "אורוגוואי",
    "Uzbekistan" : "אוזבקיסטן",
    "Venezuela" : "ונצואלה",
    "Vietnam" : "וייטנאם",
    "Vanuatu" : "ונואטו",
    "Yemen" : "תימן",
    "South Africa" : "דרום אפריקה",
    "Zambia" : "זמביה",
    "Zimbabwe" : "זימבבואה",
    "Your Nextcloud account" : "חשבון ה־Nextcloud שלך",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "הנתונים שלך מייצגים את מי שאתה וניתן לנצל אותם לרעה בקלות. אנחנו ב־Nextcloud מאמינים שיש לך את הזכות לבחור מה קורה לנתונים שלך. הזכויות שלך מוגנות עם Nextcloud כפי שמופיע בהצהרת נתוני המשתמשים!",
    "User Data Manifesto 2.0" : "הצהרת נתוני המשתמשים 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "הגדרת זכויות בסיסיות לשליטתם של האנשים בנתונים שלהם עצמם בעידן האינטרנט",
    "Control" : "שליטה",
    "over user data access" : "בגישה לנתוני משתמשים",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "הנתונים שנשלחים בצורה רצונית ומפורשת על ידי המשתמש אמורים להיות תחת שליטת המשתמש. למשתמשים אמורה להיות היכולת להחליט למי להעניק גישה ישירה לנתונים שלהם ותחת אילו הרשאות ורישיונות יש לאפשר את הגישה הזאת.",
    "Knowledge" : "ידע",
    "of how the data is stored" : "על אופן אחסון הנתונים",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "כאשר הנתונים נשלחים לספק שירות מסוים, יש ליידע את המשתמשים בנוגע למיקום בו ספק השירות מאחסן את הנתונים, למשך כמה זמן, תחת איזו סמכות מקומית ספק השירות פועל ואילו חוקים חלים.",
    "Freedom" : "חופש",
    "to choose a platform" : "לבחור פלטפורמה",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "המשתמשים יכולים לחלץ את הנתונים שלהם מהשירות בכל עת ללא אף נעילת ספק. כדי להבטיח זאת נדרש יישום מובנה של סוגי קבצים ופרוטוקולים שהכרחיים לתהליך.",
    "Learn more ↗" : "מידע נוסף ↖ ",
    "Where is your data?" : "איפה הנתונים שלך?",
    "Who has access to your data?" : "למי יש גישה לנתונים שלך?",
    "Administrators" : "מנהלים",
    "People you shared with" : "אנשים אתם שיתפת",
    "Privacy policy" : "מדיניות פרטיות",
    "Read the privacy policy." : "הצגת מדיניות הפרטיות.",
    "Encryption" : "הצפנה"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
